Exception: VoiceML::Error
- Inherits:
-
StandardError
- Object
- StandardError
- VoiceML::Error
- Defined in:
- lib/voiceml/errors.rb
Overview
Base class for every error raised by this SDK. Catch ‘VoiceML::Error` to handle them all.
Base class for every error raised by this SDK. Catch ‘VoiceML::Error` to handle them all.