Class: VoiceML::MessagingV1Resource
- Inherits:
-
Object
- Object
- VoiceML::MessagingV1Resource
- Defined in:
- lib/voiceml/resources/messaging_v1.rb
Overview
client.messaging_v1 — Twilio Messaging v1 (messaging.twilio.com/v1).
The whole group is routed at the messaging host (messaging.voicetel.com) by the
client, which is what disambiguates a Messaging Service (MG...) from a
Conversation Service (IS...) — they share the /v1/Services path shape.
Instance Attribute Summary collapse
-
#services ⇒ Object
readonly
Returns the value of attribute services.
Instance Method Summary collapse
-
#initialize(transport) ⇒ MessagingV1Resource
constructor
A new instance of MessagingV1Resource.
Constructor Details
#initialize(transport) ⇒ MessagingV1Resource
Returns a new instance of MessagingV1Resource.
13 14 15 |
# File 'lib/voiceml/resources/messaging_v1.rb', line 13 def initialize(transport) @services = MessagingV1ServicesResource.new(transport) end |
Instance Attribute Details
#services ⇒ Object (readonly)
Returns the value of attribute services.
11 12 13 |
# File 'lib/voiceml/resources/messaging_v1.rb', line 11 def services @services end |